#' @method plot bspline_series
#' @title Plot b-splines basis summation series.
#'
#' @param x A \code{\link{bspline_series}} object.
#' @param y Ignored. Present for consistency with the generic \code{plot()} function.
#' @param ... other parameters to be passed through to plotting functions.
#'
#' @importFrom utils modifyList
#' @author Heyang Ji
#' @export
#' @examples
#' bsb = bspline_basis(
#' Boundary.knots = c(0,24),
#' intercept      = TRUE,
#' df             = NULL,
#' degree         = 3
#' )
#' bss = bspline_series(
#' coef = c(2,1,1.5,3),
#' bspline_basis = bsb
#' )
#' plot(bss)

setMethod("plot",
          signature(x="bspline_series"),
          function(x,...){

            t = x@bspline_basis@Boundary.knots[1] + diff(x@bspline_basis@Boundary.knots)*(0:1000/1000)
            y = bsplineSeries2fun(x,t)

            defaults <- list(
              x    = t,
              y    = y,
              xlab = "Domain",
              ylab = "Series value",
              main = "B-splines Series"
            )
            user_args <- list(...)

            final_args <- utils::modifyList(defaults, user_args)

            do.call(plot, final_args)

            # plot(x = t, y = bsplineSeries2fun(x,t),
            #      xlab = "Domain",
            #      ylab = "Series value",
            #      main = "B-splines Series",...)
          })
# plot.bspline_series = function(x){
#   t = x@bspline_basis@Boundary.knots[1] + diff(x@bspline_basis@Boundary.knots)*(0:1000/1000)
#   plot(x = t, y = bsplineSeries2fun(x,t),
#        xlab = "x",
#        ylab = "Series value",
#        main = "Curve of the B-splines Series within a period")
# }
